@@ -54,6 +54,24 @@ impl<T: ArchivePointee + ?Sized> ArchivedBox<T> {
             metadata_resolver: value.serialize_metadata(serializer)?,
         })
     }
+
+    #[doc(hidden)]
+    #[inline]
+    pub fn is_null(&self) -> bool {
+        self.0.is_null()
+    }
+}
+
+impl<T: ArchivePointee + ?Sized> ArchivedBox<T>
+where
+    T::ArchivedMetadata: Default,
+{
+    #[doc(hidden)]
+    #[inline]
+    pub unsafe fn emplace_null(pos: usize, out: *mut Self) {
+        let (fp, fo) = out_field!(out.0);
+        RelPtr::emplace_null(pos + fp, fo);
+    }
 }
 
 impl<T: ArchivePointee + ?Sized> AsRef<T> for ArchivedBox<T> {
@@ -105,6 +123,13 @@ impl<T: ArchivePointee + hash::Hash + ?Sized> hash::Hash for ArchivedBox<T> {
     }
 }
 
+impl<T: ArchivePointee + Ord + ?Sized> Ord for ArchivedBox<T> {
+    #[inline]
+    fn cmp(&self, other: &Self) -> cmp::Ordering {
+        self.as_ref().cmp(other.as_ref())
+    }
+}
+
 impl<T: ArchivePointee + PartialEq<U> + ?Sized, U: ArchivePointee + ?Sized>
     PartialEq<ArchivedBox<U>> for ArchivedBox<T>
 {
