@@ -1,19 +1,23 @@
 use crate::{
     collections::util::Entry,
+    niche::option_box::{ArchivedOptionBox, OptionBoxResolver},
     ser::{ScratchSpace, Serializer},
     string::{ArchivedString, StringResolver},
     vec::{ArchivedVec, VecResolver},
-    with::{ArchiveWith, AsOwned, AsVec, DeserializeWith, SerializeWith},
-    Archive, Deserialize, Fallible, Serialize,
+    with::{ArchiveWith, AsOwned, AsVec, DeserializeWith, Niche, SerializeWith},
+    Archive, ArchiveUnsized, ArchivedMetadata, Deserialize, DeserializeUnsized, Fallible,
+    Serialize, SerializeUnsized,
 };
 #[cfg(not(feature = "std"))]
 use alloc::{
     borrow::Cow,
+    boxed::Box,
     collections::{BTreeMap, BTreeSet},
 };
 #[cfg(feature = "std")]
 use std::{
     borrow::Cow,
+    boxed::Box,
     collections::{BTreeMap, BTreeSet},
 };
 
@@ -267,3 +271,54 @@ where
         Ok(result)
     }
 }
+
+// Niche
+
+impl<T: ArchiveUnsized + ?Sized> ArchiveWith<Option<Box<T>>> for Niche
+where
+    ArchivedMetadata<T>: Default,
+{
+    type Archived = ArchivedOptionBox<T::Archived>;
+    type Resolver = OptionBoxResolver<T::MetadataResolver>;
+
+    unsafe fn resolve_with(
+        field: &Option<Box<T>>,
+        pos: usize,
+        resolver: Self::Resolver,
+        out: *mut Self::Archived,
+    ) {
+        ArchivedOptionBox::resolve_from_option(field.as_deref(), pos, resolver, out);
+    }
+}
+
+impl<T, S> SerializeWith<Option<Box<T>>, S> for Niche
+where
+    T: SerializeUnsized<S> + ?Sized,
+    S: Serializer + ?Sized,
+    ArchivedMetadata<T>: Default,
+{
+    fn serialize_with(
+        field: &Option<Box<T>>,
+        serializer: &mut S,
+    ) -> Result<Self::Resolver, S::Error> {
+        ArchivedOptionBox::serialize_from_option(field.as_deref(), serializer)
+    }
+}
+
+impl<T, D> DeserializeWith<ArchivedOptionBox<T::Archived>, Option<Box<T>>, D> for Niche
+where
+    T: ArchiveUnsized + ?Sized,
+    T::Archived: DeserializeUnsized<T, D>,
+    D: Fallible + ?Sized,
+{
+    fn deserialize_with(
+        field: &ArchivedOptionBox<T::Archived>,
+        deserializer: &mut D,
+    ) -> Result<Option<Box<T>>, D::Error> {
+        if let Some(value) = field.as_ref() {
+            Ok(Some(value.deserialize(deserializer)?))
+        } else {
+            Ok(None)
+        }
+    }
+}
