@@ -455,3 +455,10 @@ pub struct AsOwned;
 /// ```
 #[derive(Debug)]
 pub struct AsVec;
+
+/// A wrapper that niches some type combinations.
+///
+/// A common type combination is `Option<Box<T>>`. By using a null pointer, the archived version can
+/// save some space on-disk.
+#[derive(Debug)]
+pub struct Niche;
